@@ -55,25 +55,25 @@
 
 #if defined(_MSC_VER) && _MSC_VER >= 1300
 #if defined(_WIN64_) || defined(__WIN64__)     
-#define RLL_SUFFIX ".x64"
+#define RLL_SUFFIX "x64"
 #elif defined(_M_IX86)
-#define RLL_SUFFIX ".x86"
+#define RLL_SUFFIX "x86"
 #else
-#define RLL_SUFFIX ".xlo"
+#define RLL_SUFFIX "xlo"
 #endif
 #endif 
 
 #if defined(__MINGW32__) | defined(__CYGWIN32__)
-#define RLL_SUFFIX ".dso"
+#define RLL_SUFFIX "dso"
 #endif
 
 #ifdef  W32
 #ifndef RLL_SUFFIX
-#define RLL_SUFFIX ".rll"
+#define RLL_SUFFIX "rll"
 #endif
 #endif 
 
 #ifndef RLL_SUFFIX
-#define RLL_SUFFIX ".dso"
+#define RLL_SUFFIX "dso"
 #endif 
 
