@@ -603,7 +603,7 @@ retry:
 		}
 
 		if(server)
-	                server->errlog("access", path);
+	                errlog("access", "cannot load %s", path);
                 return NULL;
         }
 
@@ -611,7 +611,7 @@ retry:
         if(!dso->isValid())
         {
 		if(server)
-	                server->errlog("error", dso->getError());
+	                errlog("error", "%s: %s", path, dso->getError());
                 return NULL;
         }
         return get(id);  
