@@ -1160,7 +1160,13 @@ bool Methods::scrBuild(void)
 bool Methods::scrPrompt(void)
 {
 	unsigned count = 0;
-	const char *cp;
+	const char *cp = getMember();
+
+	if(cp && stricmp(translator->getId(), cp))
+	{
+		advance();
+		return true;
+	}
 
 	if(state.menu && *dtmf_digits)
 	{
@@ -1326,7 +1332,13 @@ bool Methods::scrAppend(void)
 bool Methods::scrPlay(void)
 {
 	unsigned count = 0;
-	const char *cp;
+	const char *cp = getMember();
+
+        if(cp && stricmp(translator->getId(), cp))
+        {
+                advance();
+                return true;
+        } 
 
         memset(&state.audio, 0, sizeof(state.audio));
 	audio.offset = NULL;
