@@ -296,46 +296,6 @@ void Runtime::errlog(const char *level, const char *msg)
 #endif
 }
 
-void errlog(const char *level, const char *fmt, ...)
-{
-	char *m;
-        char buffer[256];
-	va_list args;
-
-        va_start(args, fmt);
-        vsnprintf(buffer, sizeof(buffer) - 1, fmt, args);
-
-	m = strchr(buffer, '\n');
-	if(m)
-		*m = 0;
-
-	if(!stricmp(level, "debug"))
-	{
-		slog.debug() << buffer << endl;
-		return;
-	}
-	else if(!stricmp(level, "missing"))
-		slog.warn() << buffer << endl;
-	else if(!stricmp(level, "access"))
-		slog.warn() << buffer << endl;
-	else if(!stricmp(level, "notice"))
-		slog.notice() << buffer << endl;
-	else if(!strnicmp(level, "warn", 4))
-	{
-		level = "warn";
-		slog.warn() << buffer << endl;
-	}
-	else if(!strnicmp(level, "crit", 4))
-	{
-		level = "fatal";
-		slog.critical() << buffer << endl;
-	} 
-	else
-		slog.error() << buffer << endl;
-	
-	runtime.errlog(level, buffer);
-}
-
 bool Runtime::isInput(Line *line)
 {
 	if(line->scr.method == (Method)&Methods::scrKeyinput)
