@@ -26,6 +26,10 @@ using namespace std;
 
 static bool test = true;
 
+static SERVICE_STATUS_HANDLE hStatus = 0;
+static SERVICE_STATUS sStatus;
+static HANDLE hDown;
+
 static BOOL WINAPI stop(DWORD code)
 {
         if(code == CTRL_LOGOFF_EVENT)
@@ -35,11 +39,10 @@ static BOOL WINAPI stop(DWORD code)
 	BayonneDriver::stop();
 
 	if(code)
-		errlog("failed", "server exiting; reason=%d", code);
+		Bayonne::errlog("failed", "server exiting; reason=%d", code);
 	else
-		errlog("notice", "server exiting; normal termination");
+		Bayonne::errlog("notice", "server exiting; normal termination");
 
-	exit(code);
 	return TRUE;
 }
 
@@ -63,11 +66,11 @@ static RETSIGTYPE stop(int signo)
 	BayonneDriver::stop();
 
         if(signo == -2)
-                errlog("failed", "server exiting; no timeslots allocated");
+                Bayonne::errlog("failed", "server exiting; no timeslots allocated");
         else if(signo)
-                errlog("failed", "server exiting; reason=%d", signo);
+                Bayonne::errlog("failed", "server exiting; reason=%d", signo);
         else
-                errlog("notice", "server exiting; normal termination");
+                Bayonne::errlog("notice", "server exiting; normal termination");
 
 #ifdef	HAVE_LIBEXEC
 	Libexec::cleanup();
@@ -179,7 +182,7 @@ start:
 
 	Bayonne::reload();
 	BayonneService::start();
-	errlog("notice", "%s driver started; %d timeslot(s) used", dname, count);
+	Bayonne::errlog("notice", "%s driver started; %d timeslot(s) used", dname, count);
 #ifndef	WIN32
         Process::setPosixSignal(SIGPIPE, SIG_IGN);
         Process::setPosixSignal(SIGINT, &stop);
@@ -204,13 +207,75 @@ static void logging(void)
 		slog.level(Slog::levelDebug);
 }
 
+#ifdef	WIN32
+
+static void control(DWORD request)
+{
+	switch(request)
+	{
+	case SERVICE_CONTROL_SHUTDOWN:
+	case SERVICE_CONTROL_STOP:
+		BayonneService::stop();
+		BayonneDriver::stop();
+		Bayonne::errlog("notice", "server exiting; service shutdown");
+		sStatus.dwWin32ExitCode = 0;
+		sStatus.dwCurrentState = SERVICE_STOPPED;
+		SetServiceStatus(hStatus, &sStatus);
+		SetEvent(hDown);
+		return;
+	}
+	SetServiceStatus(hStatus, &sStatus);
+}
+
+static VOID service(DWORD argc, LPTSTR *argv)
+{
+	hStatus = RegisterServiceCtrlHandler("Bayonne", (LPHANDLER_FUNCTION)control);
+	hDown = CreateEvent(0, TRUE, FALSE, 0);
+
+	if(!hStatus || !hDown)
+		return;
+
+	sStatus.dwServiceType = SERVICE_WIN32;
+	sStatus.dwCurrentState = SERVICE_START_PENDING;
+	sStatus.dwControlsAccepted = 0;
+	sStatus.dwWin32ExitCode = 0;
+	sStatus.dwServiceSpecificExitCode = 0;
+	sStatus.dwCheckPoint = 0;
+	sStatus.dwWaitHint = 500;
+
+	SetServiceStatus(hStatus, &sStatus);
+
+	logging();
+    Bayonne::errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
+		VERSION, keyserver.getLast("cpu"), keyserver.getLast("platform"),
+		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
+
+	loading();
+	sStatus.dwCurrentState = SERVICE_RUNNING;
+	sStatus.dwControlsAccepted = SERVICE_ACCEPT_STOP | SERVICE_ACCEPT_SHUTDOWN;
+	sStatus.dwWin32ExitCode = 0;
+	sStatus.dwWaitHint = 0;
+	SetServiceStatus(hStatus, &sStatus);
+
+	WaitForSingleObject(hDown, INFINITE);
+	return;
+};
+
+static SERVICE_TABLE_ENTRY services[] =
+{
+	{"Bayonne", (LPSERVICE_MAIN_FUNCTION)service},
+	{NULL, NULL}
+};
+
+#endif
+
 static void testing(char **argv)
 {
 	testConfig(*argv);		
 	parseConfig(argv);
 	logging();
 
-	errlog("notice", "testing %s on %s %s; driver=%s, timeslots=%s",
+	Bayonne::errlog("notice", "testing %s on %s %s; driver=%s, timeslots=%s",
 		VERSION, 
 		keyserver.getLast("cpu"), keyserver.getLast("platform"),
 		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
@@ -229,13 +294,22 @@ static void starting(char **argv, bool trace)
         Process::setScheduler(keyengine.getLast("scheduler"));
 #ifdef	WIN32
 //	Process::setUser(keyserver.getLast("user"));
+	if(!trace)
+	{
+		if(StartServiceCtrlDispatcher(services) == FALSE)
+		{
+			Bayonne::errlog("fatel", "service failed to start");
+			stop(-1);
+		}
+		return;
+	}
 #else
 	Process::setPriority(atoi(keyengine.getLast("priority")));
 	if(!getuid())
 	{
 		if(!Process::setUser(keyserver.getLast("user")))
 		{
-			errlog("fatal", "%s: cannot set user",
+			Bayonne::errlog("fatal", "%s: cannot set user",
 				keyserver.getLast("user"));
 			stop(-1);
 		}
@@ -247,7 +321,7 @@ static void starting(char **argv, bool trace)
 #endif
 	
 	logging();
-        errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
+        Bayonne::errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
 		VERSION,
                 keyserver.getLast("cpu"), keyserver.getLast("platform"),
 		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
@@ -292,12 +366,20 @@ int main(int argc, char **argv)
 
 	if(!stricmp(cp, "-version"))
 		version();
+	else if(!stricmp(cp, "-debug"))
+	{
+		Mutex::setDebug(true);
+		testing(argv);
+	}
 	else if(!stricmp(cp, "-test"))
 		testing(argv);
-	else if(!stricmp(cp, "-trace"))
+	else if(!stricmp(cp, "-trace") || !stricmp(cp, "-load"))
 		starting(argv, true);
 	else if(!stricmp(cp, "-start"))
+	{
 		starting(argv, false);
+		return 0;
+	}
 	else if(!stricmp(cp, "-dump-install"))
 	{
 		loadConfig();
